@@ -1,3 +1,6 @@
+#
+# Copyright 2010 Ruediger Gad <r.c.g@gmx.de>
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -13,20 +16,10 @@
 
 import hildon
 import gtk
-import os
-import sys
 
-from KeyMappings import *
 from ZeeButton import ZeeButton
 from Zeemote import ZeeDiscover
 
-# If a user config directoryis present try to load mappings
-# from there.
-userConfigPath = os.getenv("HOME") + "/.zeecontrol"
-if os.path.isdir(userConfigPath):
-  sys.path.append(userConfigPath)
-  from UserMappings import *
-
 class ZeecontrolGUI(hildon.Program):
   def __init__(self):
     hildon.Program.__init__(self)
@@ -66,42 +59,42 @@ class ZeecontrolGUI(hildon.Program):
     buttonBox2.show()
 
     self.buttonA = gtk.Button("A")
-    self.buttonA.connect("clicked", self.setMapping, mappingA, altMappingA)
+    self.buttonA.connect("clicked", self.setMapping, "A")
     buttonBox1.pack_start(self.buttonA, True, True, 0)
     self.buttonA.show()
 
     self.buttonB = gtk.Button("B")
-    self.buttonB.connect("clicked", self.setMapping, mappingB, altMappingB)
+    self.buttonB.connect("clicked", self.setMapping, "B")
     buttonBox1.pack_start(self.buttonB, True, True, 0)
     self.buttonB.show()
 
     self.buttonC = gtk.Button("C")
-    self.buttonC.connect("clicked", self.setMapping, mappingC, altMappingC)
+    self.buttonC.connect("clicked", self.setMapping, "C")
     buttonBox1.pack_start(self.buttonC, True, True, 0)
     self.buttonC.show()
 
     self.buttonD = gtk.Button("D")
-    self.buttonD.connect("clicked", self.setMapping, mappingD, altMappingD)
+    self.buttonD.connect("clicked", self.setMapping, "D")
     buttonBox1.pack_start(self.buttonD, True, True, 0)
     self.buttonD.show()
 
     self.buttonE = gtk.Button("E")
-    self.buttonE.connect("clicked", self.setMapping, mappingE, altMappingE)
+    self.buttonE.connect("clicked", self.setMapping, "E")
     buttonBox2.pack_start(self.buttonE, True, True, 0)
     self.buttonE.show()
 
     self.buttonF = gtk.Button("F")
-    self.buttonF.connect("clicked", self.setMapping, mappingF, altMappingF)
+    self.buttonF.connect("clicked", self.setMapping, "F")
     buttonBox2.pack_start(self.buttonF, True, True, 0)
     self.buttonF.show()
 
     self.buttonG = gtk.Button("G")
-    self.buttonG.connect("clicked", self.setMapping, mappingG, altMappingG)
+    self.buttonG.connect("clicked", self.setMapping, "G")
     buttonBox2.pack_start(self.buttonG, True, True, 0)
     self.buttonG.show()
 
     self.buttonH = gtk.Button("H")
-    self.buttonH.connect("clicked", self.setMapping, mappingH, altMappingH)
+    self.buttonH.connect("clicked", self.setMapping, "H")
     buttonBox2.pack_start(self.buttonH, True, True, 0)
     self.buttonH.show()
         
@@ -110,8 +103,8 @@ class ZeecontrolGUI(hildon.Program):
     while gtk.events_pending():
       gtk.main_iteration()                
    
-  def setMapping(self, widget, newMapping=None, newAltMapping=None):
-    self.selectedZeeButton.setMapping(newMapping, newAltMapping)
+  def setMapping(self, widget, newMapping=None):
+    self.selectedZeeButton.setMapping(newMapping)
 
   def setSelectedZeeButton(self, zeeButton):
     self.selectedZeeButton = zeeButton
